Package: dawnn
Title: Differential Abundance with Neural Networks
Version: 2.1.1
Authors@R: 
    c(person(given = "George",
             family = "Hall",
             role = c("aut", "cre"),
             email = "george.hall@ucl.ac.uk",
             comment = c(ORCID = "0000-0002-4828-0668")),
      person(given = "Sergi",
             family = "Castellano",
             role = c("aut"),
             email = "s.castellano@ucl.ac.uk",
             comment = c(ORCID = "0000-0002-5819-4210")),
      person(given = "University College London",
             role = c("cph")))
Description: Detects regions of differential abundance in single-cell
    transcriptomic data by applying a pre-trained neural network model to the
    labels of each cell's nearest neighbours. Tests for both local and global
    differential abundance, controlling the false discovery rate with the
    Benjamini-Yekutieli procedure. The method is described in Hall and
    Castellano (2023) <doi:10.1101/2023.05.05.539427>.
License: GPL (>= 3)
Encoding: UTF-8
Imports: stats, Seurat, reticulate, keras, utils, withr, tools
Depends: R (>= 4.0.0)
Suggests: rmarkdown, knitr, testthat (>= 3.1.7), callr, dplyr, pkgload,
        viridis
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://george-hall-ucl.github.io/dawnn/,
        https://github.com/george-hall-ucl/dawnn
BugReports: https://github.com/george-hall-ucl/dawnn/issues
SystemRequirements: Python (>= 3.9) with TensorFlow (>= 2.0), typically
        installed in a conda environment and selected via the
        'tf_conda_env' argument of run_dawnn(). See the package
        documentation for setup instructions.
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-21 19:03:16 UTC; georgehall2
Author: George Hall [aut, cre] (ORCID: <https://orcid.org/0000-0002-4828-0668>),
  Sergi Castellano [aut] (ORCID: <https://orcid.org/0000-0002-5819-4210>),
  University College London [cph]
Maintainer: George Hall <george.hall@ucl.ac.uk>
Repository: CRAN
Date/Publication: 2026-09-01 08:40:09 UTC
