<br>
<p align="center">
  <img src="man/figures/logo_hires.png" width="150">
  <br><br>
  Dawnn is a method to detect differential abundance in a single-cell
  transcriptomic dataset.
</p>

<p align=center>For installation and usage instructions, see Dawnn's <a href=https://george-hall-ucl.github.io/dawnn/>documentation.</a></p>
