% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{load_model_from_python}
\alias{load_model_from_python}
\title{Load the neural network model from its .hdf5 file.}
\usage{
load_model_from_python(model_path)
}
\arguments{
\item{model_path}{String containing the path to the model's .hdf5 file.}
}
\value{
The loaded model.
}
\description{
Load the neural network model from its .hdf5 file.
}
\keyword{internal}
