% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{determine_if_region_da}
\alias{determine_if_region_da}
\title{Determine whether each cell is in a region of differential abundance.}
\usage{
determine_if_region_da(p_vals, alpha)
}
\arguments{
\item{p_vals}{Numeric vector of p-values.}

\item{alpha}{Numeric target false discovery rate supplied to the
Benjamini–Yekutieli procedure.}
}
\value{
Boolean vector containing Dawnn's verdict for each cell.
}
\description{
\code{determine_if_region_da()} takes a vector of p-values and uses
the Benjamini–Yekutieli procedure to determine whether a cell is in a
region of differential abundance.
}
\keyword{internal}
