% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{dawnn_default_model_file}
\alias{dawnn_default_model_file}
\title{Default path where Dawnn stores its downloaded model.}
\usage{
dawnn_default_model_file()
}
\value{
String path to the model file.
}
\description{
Default path where Dawnn stores its downloaded model.
}
\keyword{internal}
