% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{generate_neighbor_labels}
\alias{generate_neighbor_labels}
\title{Generate a matrix of the labels of the 1,000 nearest neighbors of each cell.}
\usage{
generate_neighbor_labels(cells, verbose, label_names, label_pos_lfc)
}
\arguments{
\item{cells}{Seurat object containing the dataset.}

\item{verbose}{Boolean verbosity.}

\item{label_names}{String containing the name of the meta.data slot in
\code{cells} containing the labels of each cell.}

\item{label_pos_lfc}{String containing the name of the label associated with
positive log-fold change.}
}
\value{
A data frame containing the labels of the 1000 nearest neighbors of
each cell.
}
\description{
Generate a matrix of the labels of the 1,000 nearest neighbors of each cell.
}
\keyword{internal}
