% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{download_model}
\alias{download_model}
\title{Download the neural network model used by Dawnn.}
\usage{
download_model(
  model_url = NULL,
  model_file_path = NULL,
  download_method = "auto",
  download_timeout = 600
)
}
\arguments{
\item{model_url}{String url from which to download the model.}

\item{model_file_path}{String path at which to save the downloaded model.}

\item{download_method}{String download program to use (e.g. wget, curl etc).}

\item{download_timeout}{Integer number of seconds before download times out
(optional, default = 600).}
}
\value{
Message confirming the absolute path to the downloaded model.
}
\description{
\code{download_model()} downloads the neural network model used by
Dawnn, which is too large to be bundled with the package. This function must
be used once before run_dawnn() can be executed. After this, the path to the
model can be passed to this function.
}
\examples{
\dontrun{
download_model()
}
}
