% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{beta_method_of_moments}
\alias{beta_method_of_moments}
\title{Estimate the parameters of a beta distribution using the method of moments.}
\usage{
beta_method_of_moments(data)
}
\arguments{
\item{data}{Vector of numbers for which to estimate the parameters.}
}
\value{
A list containing the two parameters of the fitted beta distribution.
}
\description{
Estimate the parameters of a beta distribution using the method of moments.
}
\keyword{internal}
