% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{generate_p_vals}
\alias{generate_p_vals}
\title{Generate p-values for observed Dawnn model outputs.}
\usage{
generate_p_vals(scores, null_dist)
}
\arguments{
\item{scores}{Numeric vector containing observed output of Dawnn.}

\item{null_dist}{Numeric vector containing null distribution of scores.}
}
\value{
Numeric vector containing a p-value for each cell, i.e. the
probability of observing at least such an extreme score for a cell given the
beta distribution fitted to the null distribution of scores.
}
\description{
\code{generate_p_vals()} takes Dawnn model outputs and a null
distribution and returns p-values of the observed outputs.
}
\keyword{internal}
