% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{generate_null_dist}
\alias{generate_null_dist}
\title{Generate a null distribution of P(Condition_1) estimates.}
\usage{
generate_null_dist(
  cells,
  model,
  label_names,
  label_pos_lfc,
  verbosity,
  da_mode = c("lda", "gda")
)
}
\arguments{
\item{cells}{Seurat object containing the dataset.}

\item{model}{Loaded neural network model to use.}

\item{label_names}{String containing the name of the meta.data slot in
\code{cells} containing the labels of each cell.}

\item{label_pos_lfc}{String containing the name of the label associated with
positive log-fold change.}

\item{verbosity}{Integer how much output to print. 0: silent; 1: normal
output; 2: display messages from predict() function.}

\item{da_mode}{String containing the type of differential abundance being
sought, either "lda" (local DA) or "gda" (global DA).}
}
\value{
A vector containing a null distribution of Dawnn's model outputs for
shuffled sample labels.
}
\description{
\code{generate_null_dist()} shuffles the sample labels three times
and returns the estimates of P(Condition_1) for each shuffled dataset.
}
\keyword{internal}
