% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dawnn.R
\name{param_check}
\alias{param_check}
\title{Sanity check input parameters}
\usage{
param_check(cells, label_names, label_pos_lfc, reduced_dim, recalculate_graph)
}
\arguments{
\item{cells}{Seurat object containing the dataset.}

\item{label_names}{String containing the name of the meta.data slot in
\code{cells} containing the labels of each cell.}

\item{label_pos_lfc}{String containing the name of the label associated with
positive log-fold change.}

\item{reduced_dim}{String containing the name of the dimensionality
reduction to use.}

\item{recalculate_graph}{Boolean whether to recalculate the KNN graph. If
FALSE, then the one stored in the \code{cells} object will be used (optional,
default = TRUE).}
}
\value{
TRUE if all parameters sane, otherwise stop execution with error
message.
}
\description{
\code{param_check()} verifies that the parameters passed to
run_dawnn() are sane.
}
\keyword{internal}
